@@ -9,11 +9,11 @@ Template::ShowStartStop - Display where template's start and stop
 
 =head1 VERSION
 
-Version 0.03
+Version 0.04
 
 =cut
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 =head1 SYNOPSIS
 
@@ -72,10 +72,12 @@ foreach my $sub ( qw( process ) ) {
 
 		my $processed_data = $super->($self, $what, @_);
 
-		return <<END
-<!-- START: $sub $template -->
-$processed_data<!-- STOP:  $sub $template -->
-END
+		my $output
+			= "<!-- START: $sub $template -->\n"
+			. "$processed_data<!-- STOP:  $sub $template -->\n"
+			;
+
+		return $output;
 	}; # sub
 } # for
 
